#
# spec file for package python-bqplot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# https://github.com/bqplot/bqplot/issues/1639
%define skip_python312 1
%define         pyver 0.12.43
%define         jupver 0.5.44
Name:           python-bqplot
Version:        %{pyver}
Release:        8.1
Summary:        Interactive plotting package for the Jupyter notebook
License:        Apache-2.0
URL:            https://github.com/bqplot/bqplot
# bundled js stuff from PyPI sdist
Source0:        https://files.pythonhosted.org/packages/source/b/bqplot/bqplot-%{pyver}.tar.gz
# tests from GitHub source
Source1:        https://github.com/bqplot/bqplot/archive/refs/tags/%{pyver}.tar.gz#/bqplot-%{pyver}-gh.tar.gz
BuildRequires:  %{python_module jupyter-packaging}
BuildRequires:  %{python_module jupyterlab}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  jupyter-jupyterlab-filesystem >= 20211114
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  python-rpm-macros
Requires:       jupyter-bqplot-notebook = %{jupver}
Requires:       python-numpy >= 1.10.4
Requires:       python-traitlets >= 4.3.0
Requires:       python-traittypes >= 0.0.6
Requires:       (python-ipywidgets >= 7.5.0 with python-ipywidgets < 9)
Requires:       (python-pandas >= 1 with python-pandas < 3)
Provides:       python-jupyter_bqplot = %{pyver}
Obsoletes:      python-jupyter_bqplot < %{pyver}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipywidgets >= 7.5.0 with %python-ipywidgets < 9}
BuildRequires:  %{python_module nbval}
BuildRequires:  %{python_module numpy >= 1.10.4}
BuildRequires:  %{python_module pandas >= 1 with %python-pandas < 3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module traitlets >= 4.3.0}
BuildRequires:  %{python_module traittypes >= 0.0.6}
# /SECTION
%python_subpackages

%description
Plotting system for the Jupyter notebook based on the
interactive Jupyter widgets.

This package provides the python interface.

%package     -n jupyter-bqplot-notebook
Version:        %{jupver}
Summary:        Interactive plotting package for Jupyter Notebooke
Requires:       jupyter-notebook
Requires:       python3dist(bqplot) = %{pyver}
Provides:       jupyter-bqplot =  %{pyver}-%{release}
# the jupyter-bqplot rpm package had the python package version until 0.12.13
Obsoletes:      jupyter-bqplot <  %{pyver}-%{release}

%description -n jupyter-bqplot-notebook
Plotting system for the Jupyter notebook based on the
interactive Jupyter widgets.

This package provides the jupyter notebook extension.

%package     -n jupyter-bqplot-jupyterlab
Version:        %{jupver}
Summary:        Interactive plotting package for Jupyterlab
Requires:       jupyter-jupyterlab
Requires:       python3dist(bqplot) = %{pyver}

%description -n jupyter-bqplot-jupyterlab
Plotting system for the Jupyter notebook based on the
interactive Jupyter widgets.

This package provides the jupyterlab extension.

%prep
%setup -q -n bqplot-%{pyver}
tar -x --strip-components=1 -f %{SOURCE1} bqplot-%{pyver}/{tests,ui-tests}
rm bqplot/install.py

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{_jupyter_prefix}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -c "import bqplot"
# dtype no longer unsupported
donttest="test_dtype_with_str"
%pytest tests/  -k "not ($donttest)"
%pytest --nbval ui-tests/tests/notebooks

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/bqplot/
%{python_sitelib}/bqplot-%{pyver}.dist-info

%files -n jupyter-bqplot-notebook
%license LICENSE
%_jupyter_config %{_jupyter_nb_notebook_confdir}/bqplot.json
%{_jupyter_nbextension_dir}/bqplot/

%files -n jupyter-bqplot-jupyterlab
%license LICENSE
%{_jupyter_labextensions_dir3}/bqplot/

%changelog
* Fri Jul 12 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.12.43
  * fix: domain should not be reset when min/max are set #1638
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (through
  ipywidgets)
* Fri Feb  9 2024 Ben Greiner <code@bnavigator.de>
- Don't build for python312 yet: ui-test failure of unknown reason
  gh#bqplot/bqplot#1639
* Sat Dec 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.12.42, jupyter frontend 0.5.43
  * fix: set domain to (0, 1) when no data is present by
    @maartenbreddels in #1619
* Sat Oct 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.12.40
  * fix: remove numpy upper bound pin by @maartenbreddels in #1601
  * fix: background color of figure was not computed properly by
    @maartenbreddels in #1603
  * fix: axis formatting depended on initial values or changes
    [#1541]
  * fix: resize not always working by @mariobuikhuizen in #1598
  * Backport PR #1511 on branch 0.12.x (Fix missing interpolation
    options) by @meeseeksmachine in #1525
  * feature: custom axis labeling from kernel side (tick_labels).
    by @maartenbreddels in #1526
  * Backport PR #1506 on branch 0.12.x (Add +, x and . as markers)
    by @meeseeksmachine in #1529
  * Backport PR #1505 on branch 0.12.x (Plotting Widgets) by
    @meeseeksmachine in #1530
  * Backport PR #1539: fix: figure is not updating when margins
    change by @mariobuikhuizen in #1581
  * Backport resize observer PR #1531 by @martinRenou in #1593
  * fix: panning in a by CSS rotated plot doesn't work correctly by
    @mariobuikhuizen in #1585
  * Fix luminowidget error for ipywidgets 7 by @martinRenou in
    [#1523]
  * Exclude tests top-level package, add some JupyterLab trove
    classifiers by @meeseeksmachine in #1518
  * Fix processPhosphorMessage for ipywidgets 7 by @meeseeksmachine
    in #1522
  * ipywidgets 8 support by @martinRenou in #1517
  * fix: line label invisible in dark theme by @meeseeksmachine in
    [#1472]
  * Add default color CSS selectors to node text by
    @meeseeksmachine in #1473
  * feat: log scale support for ScatterGL Mark by @maartenbreddels
    in #1424
  * Backport PR #1426 on branch 0.12.x (Fix index selector jumping
    back to 0) by @meeseeksmachine in #1427
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.12.31, jupyter fronted 0.5.32
  * no release notes
- Fix jupyter config paths
* Sat Apr 10 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.12.25
  * no release notes
- Add jupyterlab extension subpackage
- Use upstreams jupyter-bqplot versioning in new subpackage names
- Skip python36 build
- Tests are not in the PyPI sdist, get them from GitHub.
- No mock
- Test notebooks with nbval
* Mon Jun 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.12.13
  * Bars: Use arrow function
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.12.12:
  * Minor fixes around
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.12.3
  * Add versions lookup table in the README
  * Axis: Fix axis side validation
  * Binary Serializers: Add support for pandas.Timestamp array
  * DOC: Fix a few Sphinx warnings
  * GridHeatMap: Add tests
  * GridHeatmap: Fix selection
  * MarketMap: Fix text style at creation
  * Pie: Add tests
  * Pie: Fix Labels and data update
  * Remove unused function
  * Update tests
  * added a tutorial for building compound widgets
  * cleaned up notebook metadata hence reducing the size of the file
  * cleared metadata thereby reducing file size significantly
  * cleared metadata, fixed image path and url link to image documentation
  * cleared output cells, used pyplot to reduce code and removed redundant widgets
* Wed Jan 15 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.12.2
  * Tests: Use DOM element API for fetching the fill style
  * Hist: Add tests
  * Hist: Add support for selected_style and unselected_style in Hist
  * Hist: Remove unused method
  * Hist: Respect the 'colors' attribute when coloring the bars
  * Hist: Use same default colors value as in Bars
  * test: background color changed due to css fix
  * test: tests should include css
  * fix: screenshot CSS was missing CSS variables
  * Refactor Figure sizing logic
  * Cleaning Heatmap implementation
  * fix: make pan and zoom work with Logscale
  * fix: use z-index:0 for all layers to not overlap with higher z-index …
  * fix: avoids CORS error when building css for svg screenshot
  * fix: ColorScale can miss events because render does not return a Promise
  * add event listeners and classes to render tooltip for OHLC mark
  * add labels to bar mark
  * Add TypeScript annotations, refactoring, setters/getters
  * Bump lodash from 4.17.11 to 4.17.15 in /js
  * Bump mixin-deep from 1.3.1 to 1.3.2 in /js
  * Bump js-yaml from 3.7.0 to 3.13.1 in /js
* Mon Nov 18 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.12.1
  * Axis width fix
  * fix: call super.process_hover/click consistently and without argument as array
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.12.0
  * Add cross marker
  * Add same view padding as in the base Scatter
  * Add triangle-up triangle-down markers
  * Add validators Python side on the row and column array sizes
  * Added missing import 'd3-selection-multi'
  * Added support for cell labels
  * Attributes update refactoring
  * Binary support for all Marks and Selectors
  * Bugfix for d3.event -> d3.getEvent()
  * Bugfix for styles
  * Bugfixes to bars & hist for d3.event, and move to new processing
  * Classes to distinguish figure and interaction
  * Clean ScatterGL implementation
  * Convert Axis, Figure, Scale and Tooltip to use es2015 classes.
  * Convert Bars to es2015 classes.
  * Convert build to use TS 3.4
  * Convert scale hierarchy to use es2015 classes
  * Disable strict and noImplicitAny
  * Don’t shadow the _ global.
  * Enable webpack production mode
  * Expose python2.7 issue
  * Figure: DOM simplification for overlay pattern and small fixes
  * Figure: fix 'timing' issue with setting interact
  * Figure: fixes annoying Infinity error caused by a non-physical min_as…
  * Figure: support for pixel_ratio for WebGL pixel size control (~=retin…
  * Fix Bars multi-selection
  * Fix BoxPlot selection
  * Fix ColorScaleModel domain type
  * Fix DateColorScale
  * Fix Graph selection
  * Fix GridHeatMap color update
  * Fix GridHeatMap selection
  * Fix GridHeatMapModel model
  * Fix MarkModel model
  * Fix MarketMap color when data is NaN
  * Fix MarketMap coloring issue
  * Fix OHLCModel model
  * Fix Pie chart
  * Fix Pie selection
  * Fix PieModel model
  * Fix Scales models
  * Fix SquareMarkerMap by removing it
  * Fix animation filename in introduction.rst
  * Fix colormap creation and take color domain into account
  * Fix compilation errors in Bar.ts
  * Fix compilation errors.
  * Fix date serialization
  * Fix error message to mention bqplot
  * Fix exports
  * Fix figure model
  * Fix heatmap in the case of a reversed scale
  * Fix index
  * Fix labels models
  * Fix missing OHLC model attribute
  * Fix multiselection in the Scatter plot
  * Fix number of attributes issue for Firefox
  * Fix offset issue in OrdinalScale
  * Fix or hack around compilation errors from d3
  * Fix package.json for Jupyter Lab extension
  * Fix padding update
  * Fix rangeBand -> bandwidth
  * Fix reset_hover method name collision
  * Fix scale assignment
  * Fix tooltip color and click event for MarketMap
  * Fix tooltip layout issue
  * Fix/workaround for when nan's enter brush selector causing infinite loop
  * Fixed ColorAxis export
  * Fixed Map.ts
  * Fixed MultiSelector
  * Fixed OrdinalScale padding
  * Fixed boxplot: rangeBand -> bandwidth
  * Fixed drag in ScatterBase.ts
  * Fixed padding in ordinal scale
  * Fixed selectors
  * Fixup color axis domain
  * Import d3 by itself.
  * Inherit `process_interactions` from Mark
  * Large scatter plots using WebGL
  * Make fill_opcities work with fill=inside
  * Move mixins to duplicated code instead.
  * Only add on click handler to newly added elements. Fixes bug.
  * Only create WebGL context when needed
  * Polyfill jupyterlab CSS variables
  * Refactor event handling into subhandlers
  * Refactored marker circle,square and arrow, almost pixel perfect
  * Replaced var with const and let
  * Revert "adding labels to cells natively"
  * Revise outlier selection method
  * Set # of axis ticks for DateScale by width
  * Set auto width
  * Specify a type for THREE.Color.
  * Switch off overlay when no figure interaction
  * Update to jupyterlab 1.0
  * Upgraded to d3 v5
  * Use CSS variables
  * Use binary buffers for Map.selected attribute
  * Use const instead of let
  * Use css variables
  * Use d3-scale-chromatic to fix error
  * We never use the output of invert_pixel, so make the function return …
  * WebGL support for bqplot (threejs based)
  * accept non-numbers for data
  * accept string types at the kernel side
  * add ability to disable bar chart stroke outline
  * add square marker, and make it fast (no texture)
  * add support for Boxplot selection
  * add theme trait to Figure
  * added color data
  * added legend support
  * added support for labels in grid heat map by adding two attributes: d…
  * added support for string type (this should fix the infinite recursive…
  * adding serializer for image x,y
  * allow for nans to stay in the brush selector
  * allow scaling up of png images and have a good default for high dpi
  * bugfix: make panzoom take scale-reversal into account
  * expose bug of not supporting ordinal values in lines
  * fix array deserialization for some versions of python/numpy
  * fix scales for x, y, and size to match bqplot
  * fix scatter color updating
  * fix webgl canvas: take margin changes into account
  * fix(events): add new transparent rectangle in figure to catch events
  * fix(scattergl): color scale uniforms should update when color changes
  * fix: Upgrade to raw-loader 2 (like jupyter lab) so that we can load t…
  * fix: after changing geo, material needs updating
  * fix: always make the (webgl) canvas absolute and skip pointer events
  * fix: brush selectors threw exception with no selection, fixed order o…
  * fix: close vbox as well as figure to avoid issues with voila
  * fix: events from the background were never captured because they were…
  * fix: implement relayout for ScatterGL
  * fix: selection not using get_typed_field
  * fix: timing of relayout
  * fix: use the default value or premultipliedAlpha: true
  * fixed an issue where 'selected' wasn't getting updated on empty brush
  * fixed code where d3.format fails for null formats
  * fixes: BrushSelector was sending lists causing roundtrips
  * increased pie label font size to 12px
  * initial start for binary serialization
  * no need to call layout before marks are done (fixes a bug)
  * performance fix: Float32Array.from is slow, use a loop, 100x faster
  * prevent zero bar width and make sure plot is still drawn when bar width
  * refactor png rendering and sanity check by checking a pixel color
  * removed layout attribute, since it's causing problems on JS side
  * removed metadata and using pyplot wherever possible
  * removed setting opacity of polylines
  * renamed Mega to GL
  * respect animation_duraction of Figure
  * scaling of scatter goes as sqrt(size)
  * scatter label colors
  * silence brush events on selected_changed
  * support arrays with object type if they are all strings
  * using var(--bq-content-font-color) for pie polyline stroke
* Sat Jul 27 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.11.6
  * Update for JupyterLab 1.0
  * added cells for updating display_format and font_style
  * adding labels to cells natively
  * cleaned up code which makes selections
  * cleanup and added an example with 'freeze_tooltip_location'
  * added option to freeze/unfreeze tooltip location
  * changed selected_stroke to orangered
  * fixed paths to data files
  * centering the labels
* Tue May 14 2019 Todd R <toddrme2178@gmail.com>
- Fix dependencies
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.11.5
  * silence brush events on selected_changed
- Update to version 0.11.4
  * Scatter label color now follow theme
  * Fixup color axis domain
  * Fixup election example notebook
- Update to version 0.11.3
  * Fixup interaction layer wrt typed fields
  * Set # of axis ticks for DateScale by width
  * fixed an issue where 'selected' wasn't getting updated on empty brush
  * Revise outlier selection method
  * Fix d3 selections
  * not setting default labels in lieu of empty labels
  * increased pie label font size to 12px
  * Make fill_opcities work with fill=inside
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.11.2
  * Merge pull request #742 from ChakriCherukuri/pyplot_fix
  * fixed an issue with marker strings (default_colors renamed to colors)
  * use trait instead of setter
  * fix: empty brush updates brush.selected
  * Don't squeeze array because of single stacked bar
  * apply selected styles on redraw
  * Listen to colorscale changes in GridHeatMap
  * Adding extrapolation option for ColorScale
  * Do light/dark styling with JupyterLab theming system.
  * add auto_detect_outliers property to front-end model
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.11.1
  * Fixup notebook links
  * Fixup marker update in Scatter plot
  * package-lock update
* Wed Apr 25 2018 toddrme2178@gmail.com
- Don't need to manually enable extension.
* Sun Apr 22 2018 toddrme2178@gmail.com
- Double-check target directory.
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
